/***************************************************************
 * Simple EEPROM storage management
 */
#include "Eeprom.h"

void Eeprom_init() {
  EEPROM.begin(eeprom_size);  
}




void Eeprom_clean() {
  for(int i=0; i<eeprom_size; i++){
    EEPROM.writeByte(i,0);
  }
  EEPROM.commit(); 
}


boolean Eeprom_write(int eeprom_addr, int eeprom_len, String data) {
  
  int len = min<int>(data.length(), eeprom_len);

  for(int i=0; i<len; i++) {
    EEPROM.write(eeprom_addr  + i, data[i]);
  }
  EEPROM.write(eeprom_addr + len,'\0');   //Add termination null character for String Data
  EEPROM.commit();
  Serial.println("Eeprom_write: " + data);

  String storedData = Eeprom_read(eeprom_addr, eeprom_len);
  if (storedData == data)
    return true;
  else
    return false;
}

String Eeprom_read(int eeprom_addr, int eeprom_len) {

  char data[eeprom_len]; 
  int len=0;

  unsigned char k = EEPROM.read(eeprom_addr);
  while(k != '\0' && len<eeprom_len)   //Read until null character
  {    
    k = EEPROM.read(eeprom_addr + len);
    data[len]=k;
    len++;
  }
  data[len]='\0';
  //Serial.println("Eeprom_read: " + String(data));
  return String(data);
}
